@@ -28,43 +28,96 @@
 
 This AWS Solutions Construct implements an Amazon API Gateway connected to an Amazon SageMaker endpoint pattern.
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition:
 
-```javascript
+Typescript
+
+```python
+import { Construct } from 'constructs';
+import { Stack, StackProps } from 'aws-cdk-lib';
 import { ApiGatewayToSageMakerEndpoint, ApiGatewayToSageMakerEndpointProps } from '@aws-solutions-constructs/aws-apigateway-sagemakerendpoint';
 
 // Below is an example VTL (Velocity Template Language) mapping template for mapping the Api GET request to the Sagemaker POST request
-const requestTemplate =
-`{
+const requestTemplate = `
+{
     "instances": [
-#set( $user_id = $input.params("user_id") )
-#set( $items = $input.params("items") )
-#foreach( $item in $items.split(",") )
-    {"in0": [$user_id], "in1": [$item]}#if( $foreach.hasNext ),#end
-    $esc.newline
-#end
+        # set( $user_id = $input.params("user_id") )
+        # set( $items = $input.params("items") )
+        # foreach( $item in $items.split(",") )
+        # if( $foreach.hasNext ),#end
+        {"in0": [$user_id], "in1": [$item]}
+            $esc.newline
+        # end
     ]
-}`;
+}`
 
 // Replace 'my-endpoint' with your Sagemaker Inference Endpoint
 new ApiGatewayToSageMakerEndpoint(this, 'test-apigw-sagemakerendpoint', {
-    endpointName: 'my-endpoint',
-    resourcePath: '{user_id}',
-    requestMappingTemplate: requestTemplate
+  endpointName: 'my-endpoint',
+  resourcePath: '{user_id}',
+  requestMappingTemplate: requestTemplate
 });
 ```
 
-## Initializer
+Python
 
-```text
-new ApiGatewayToSageMakerEndpoint(scope: Construct, id: string, props: ApiGatewayToSageMakerEndpointProps);
+```python
+from aws_solutions_constructs.aws_apigateway_sagemakerendpoint import ApiGatewayToSageMakerEndpoint
+from aws_cdk import Stack
+from constructs import Construct
+
+# Below is an example VTL (Velocity Template Language) mapping template for mapping the Api GET request to the Sagemaker POST request
+request_template = """
+{
+    "instances": [
+        # set( $user_id = $input.params("user_id") )
+        # set( $items = $input.params("items") )
+        # foreach( $item in $items.split(",") )
+        # if( $foreach.hasNext ),#end
+        {"in0": [$user_id], "in1": [$item]}
+            $esc.newline
+        # end
+    ]
+}"""
+
+# Replace 'my-endpoint' with your Sagemaker Inference Endpoint
+ApiGatewayToSageMakerEndpoint(self, 'test-apigw-sagemakerendpoint',
+                                endpoint_name='my-endpoint',
+                                resource_path='{user_id}',
+                                request_mapping_template=request_template
+                                )
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`ApiGatewayToSageMakerEndpointProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awsconstructs.services.apigatewaysagemakerendpoint.*;
+
+// Create an example VTL (Velocity Template Language) mapping template for mapping the Api GET request to the Sagemaker POST request
+final String requestTemplate = "{"
+        + "\"instances\": ["
+        + "# set( $user_id = $input.params(\"user_id\") )"
+        + "# set( $items = $input.params(\"items\") )"
+        + "# foreach( $item in $items.split(\",\") )"
+        + "# if( $foreach.hasNext ),#end"
+        + "{\"in0\": [$user_id], \"in1\": [$item]}"
+        + "    $esc.newline"
+        + "# end"
+        + "]"
+        + "}";
+
+// Replace ""my-endpoint"" with your Sagemaker Inference Endpoint
+new ApiGatewayToSageMakerEndpoint(this, "ApiGatewayToSageMakerEndpointPattern",
+        new ApiGatewayToSageMakerEndpointProps.Builder()
+                .endpointName("my-endpoint")
+                .resourcePath("{user_id}")
+                .requestMappingTemplate(requestTemplate)
+                .build());
+```
 
 ## Pattern Construct Props
 
@@ -116,7 +169,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -128,6 +181,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -154,8 +209,8 @@ class ApiGatewayToSageMakerEndpoint(
         request_mapping_template: builtins.str,
         resource_path: builtins.str,
         api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.Role] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         resource_name: typing.Optional[builtins.str] = None,
         response_mapping_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -175,6 +230,10 @@ class ApiGatewayToSageMakerEndpoint(
         :since: 1.68.0
         :summary: Constructs a new instance of the ApiGatewayToSageMakerEndpoint class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToSageMakerEndpoint.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToSageMakerEndpointProps(
             endpoint_name=endpoint_name,
             request_mapping_template=request_mapping_template,
@@ -231,8 +290,8 @@ class ApiGatewayToSageMakerEndpointProps:
         request_mapping_template: builtins.str,
         resource_path: builtins.str,
         api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.Role] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         resource_name: typing.Optional[builtins.str] = None,
         response_mapping_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -252,6 +311,16 @@ class ApiGatewayToSageMakerEndpointProps:
             api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToSageMakerEndpointProps.__init__)
+            check_type(argname="argument endpoint_name", value=endpoint_name, expected_type=type_hints["endpoint_name"])
+            check_type(argname="argument request_mapping_template", value=request_mapping_template, expected_type=type_hints["request_mapping_template"])
+            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
+            check_type(argname="argument api_gateway_execution_role", value=api_gateway_execution_role, expected_type=type_hints["api_gateway_execution_role"])
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
+            check_type(argname="argument response_mapping_template", value=response_mapping_template, expected_type=type_hints["response_mapping_template"])
         self._values: typing.Dict[str, typing.Any] = {
             "endpoint_name": endpoint_name,
             "request_mapping_template": request_mapping_template,
